==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/core/requests/GetBlockVolumeReplicaRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.core.requests;

import com.oracle.bmc.core.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/core/GetBlockVolumeReplicaExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * GetBlockVolumeReplicaRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20160918")
public class GetBlockVolumeReplicaRequest
        extends com.oracle.bmc.requests.BmcRequest<java.lang.Void> {

    /** The OCID of the block volume replica. */
    private String blockVolumeReplicaId;

    /** The OCID of the block volume replica. */
    public String getBlockVolumeReplicaId() {
        return blockVolumeReplicaId;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    GetBlockVolumeReplicaRequest, java.lang.Void> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The OCID of the block volume replica. */
        private String blockVolumeReplicaId = null;

        /**
         * The OCID of the block volume replica.
         *
         * @param blockVolumeReplicaId the value to set
         * @return this builder instance
         */
        public Builder blockVolumeReplicaId(String blockVolumeReplicaId) {
            this.blockVolumeReplicaId = blockVolumeReplicaId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(GetBlockVolumeReplicaRequest o) {
            blockVolumeReplicaId(o.getBlockVolumeReplicaId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of GetBlockVolumeReplicaRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of GetBlockVolumeReplicaRequest
         */
        public GetBlockVolumeReplicaRequest build() {
            GetBlockVolumeReplicaRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Build the instance of GetBlockVolumeReplicaRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of GetBlockVolumeReplicaRequest
         */
        public GetBlockVolumeReplicaRequest buildWithoutInvocationCallback() {
            GetBlockVolumeReplicaRequest request = new GetBlockVolumeReplicaRequest();
            request.blockVolumeReplicaId = blockVolumeReplicaId;
            return request;
            // new GetBlockVolumeReplicaRequest(blockVolumeReplicaId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder().blockVolumeReplicaId(blockVolumeReplicaId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",blockVolumeReplicaId=").append(String.valueOf(this.blockVolumeReplicaId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof GetBlockVolumeReplicaRequest)) {
            return false;
        }

        GetBlockVolumeReplicaRequest other = (GetBlockVolumeReplicaRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(this.blockVolumeReplicaId, other.blockVolumeReplicaId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.blockVolumeReplicaId == null
                                ? 43
                                : this.blockVolumeReplicaId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/core/requests/GetBlockVolumeReplicaRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.core.requests;

import com.oracle.bmc.core.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/core/GetBlockVolumeReplicaExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * GetBlockVolumeReplicaRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20160918")
public class GetBlockVolumeReplicaRequest
        extends com.oracle.bmc.requests.BmcRequest<java.lang.Void> {

    /** The OCID of the block volume replica. */
    private String blockVolumeReplicaId;

    /** The OCID of the block volume replica. */
    public String getBlockVolumeReplicaId() {
        return blockVolumeReplicaId;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    GetBlockVolumeReplicaRequest, java.lang.Void> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The OCID of the block volume replica. */
        private String blockVolumeReplicaId = null;

        /**
         * The OCID of the block volume replica.
         *
         * @param blockVolumeReplicaId the value to set
         * @return this builder instance
         */
        public Builder blockVolumeReplicaId(String blockVolumeReplicaId) {
            this.blockVolumeReplicaId = blockVolumeReplicaId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(GetBlockVolumeReplicaRequest o) {
            blockVolumeReplicaId(o.getBlockVolumeReplicaId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of GetBlockVolumeReplicaRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of GetBlockVolumeReplicaRequest
         */
        public GetBlockVolumeReplicaRequest build() {
            GetBlockVolumeReplicaRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Build the instance of GetBlockVolumeReplicaRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of GetBlockVolumeReplicaRequest
         */
        public GetBlockVolumeReplicaRequest buildWithoutInvocationCallback() {
            GetBlockVolumeReplicaRequest request = new GetBlockVolumeReplicaRequest();
            request.blockVolumeReplicaId = blockVolumeReplicaId;
            return request;
            // new GetBlockVolumeReplicaRequest(blockVolumeReplicaId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder().blockVolumeReplicaId(blockVolumeReplicaId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",blockVolumeReplicaId=").append(String.valueOf(this.blockVolumeReplicaId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof GetBlockVolumeReplicaRequest)) {
            return false;
        }

        GetBlockVolumeReplicaRequest other = (GetBlockVolumeReplicaRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(this.blockVolumeReplicaId, other.blockVolumeReplicaId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.blockVolumeReplicaId == null
                                ? 43
                                : this.blockVolumeReplicaId.hashCode());
        return result;
    }
}
